<?php
/**
 * EIpToCountry class file.
 *
 * @author Cassiano Surek <cass@surek.co.uk>
 * @link http://www.yiiframework.com/
 * @copyright Copyright &copy; 2011 Cassiano Surek
 * @license http://www.yiiframework.com/license/
 */


/**
 * EIpToCountry tries to match a country based on an ip address
 *
 * This class simply tries to return the country name and ISO code based on IP by using the info from maximind.com.
 * {@link http://www.maxmind.com/app/geolitecountry }
 *
 * You may install it as an application component by adding the following to your config/main.php file:
 *
 * 		'location'=>array(
 *           'class'=>'ext.iptocountry.EIpToCountry',
 *       ),
 *
 * You can then get country name and iso code by issuing
 * Yii::app()->location->getCountryName() or Yii::app()->location->getCountryISO() wherever needed.
 *
 * @author Cassiano Surek <cass@surek.co.uk>
 */
class EIpToCountry
{
	/**
	 * @var string the detected or informed ip address
	 */
	public $ipAddress;

	/**
	 * @var int the calculated ip number
	 */
	public $ipNumber;

	/**
	 * @var string name of the country
	 */
	public $countryName;

	/**
	 * @var string the iso code of the country
	 */
	public $countryISO;

	/**
	* Let's do a lot of stuff automatically at instantitation to speed matters up
	*/
	public function __construct($ps_ip="")
	{
		try{

			// If no ip has been given, let's use the visitor's ip
			if(!$ps_ip){
				$this->ipAddress = Yii::app()->request->userHostAddress;
			}elseif($ps_ip){
				$this->ipAddress = $ps_ip;
			}else{
				throw new Exception("No IP to lookup. Please inform one or check why the remote ip could not be determined.");
			}
			// UK $this->ipAddress = "94.193.98.16";
			// Brazil - 177.40.105.124
			$ipAddrressParts = explode('.',$this->ipAddress);

			// Based on the formula at http://www.maxmind.com/app/csv, we calculate the ip Number to use on the sql query
			$this->ipNumber = 16777216*$ipAddrressParts[0] + 65536*$ipAddrressParts[1] + 256*$ipAddrressParts[2] + $ipAddrressParts[3];

			$this->findCountryInfo();

		}catch(Exception $e){
			return $e->getMessage();
		}

	}

	/**
	 * Matching the calculated ip within a specific range
	 */
	public function findCountryInfo()
	{

		// No need to bind parameters as this is not data inputted from an external source
		$ls_sql = "SELECT country_name, country_iso FROM geo_countries WHERE ".$this->ipNumber." >= begin_num AND ".$this->ipNumber." <= end_num LIMIT 1 ";
		$lo_command=Yii::app()->db->createCommand($ls_sql);
		$las_countryInfo=$lo_command->queryRow();

		//Assigning vars
		$this->countryName = $las_countryInfo['country_name'];
		$this->countryISO = $las_countryInfo['country_iso'];

	}

	/**
	 * Returning the country name
	 */
	public function getCountryName(){
		return $this->countryName;
	}

	/**
	 * Returning the country ISO code
	 */
	public function getCountryISO(){
		return $this->countryISO;
	}

	public function init(){
	}

}